import 'dart:async';
import 'dart:convert';
import 'package:flutter/widgets.dart';
import 'package:swiss_public_transport_plugin/models/station.dart';
import 'package:swiss_public_transport_plugin/models/timetable.dart';
import 'package:http/http.dart' as http;
import 'package:intl/intl.dart';

class SwissPublicTransportPlugin {


  Future<Set<Station>> getStations(String station) async {
    var response = await http.get(
        "https://transport.opendata.ch/v1/locations?query=$station&type=station");

    var jsonResponse = json.decode(response.body);

    Set<Station> stations = new Set();
    for (var jsonStation in jsonResponse['stations']) {
      stations.add(Station.fromJson(jsonStation));
    }
    return stations;
  }

  /// Connects and retrieves the Timetable for the specified paremeters
  /// where [from] is the departure and [to] the arrival. [when] specifies
  /// the time of departure
  Future<Timetable> getTimeTable({@required String from, @required String to, DateTime when, String via}) async {
    var date = DateFormat("yyyy-MM-dd").format(when);
    String time = DateFormat.Hm().format(when);

    try {
      String whenStr = "";
      String viaStr = "";
      if(when == null ){
        whenStr = "";
      }else{
        whenStr = "?date=$date&time=$time";

      }
      if(via == null || via.trim().isEmpty){
          viaStr = "";
      }else{
        viaStr = "&via=$via";
      }
      var response = await http.get(
          'https://transport.opendata.ch/v1/connections?from=$from&to=$to&limit=15$whenStr$viaStr');
      return Timetable.fromJson(json.decode(response.body));
    } catch (error) {
      print("Swiss_Public_Transport_Plugin: ERROR: " + error.toString());
      return null;
    }
  }
}
